==> de.uka.ipd.sdq.pcm.codegen.simucom.source_1.0.0.201511051246.jar: de/uka/ipd/sdq/pcm/codegen/simucom/transformations/DelegatorClassXpt.java <==
package de.uka.ipd.sdq.pcm.codegen.simucom.transformations;

import com.google.inject.Inject;
import de.uka.ipd.sdq.pcm.codegen.simucom.helper.M2TFileSystemAccess;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.JavaCoreXpt;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.JavaNamesExt;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.ProvidedPortsXpt;
import java.util.Arrays;
import org.eclipse.emf.common.util.EList;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import org.palladiosimulator.pcm.repository.InfrastructureInterface;
import org.palladiosimulator.pcm.repository.InfrastructureSignature;
import org.palladiosimulator.pcm.repository.Interface;
import org.palladiosimulator.pcm.repository.OperationInterface;
import org.palladiosimulator.pcm.repository.OperationSignature;
import org.palladiosimulator.pcm.repository.Signature;

@SuppressWarnings("all")
public class DelegatorClassXpt {
  @Inject
  private M2TFileSystemAccess fsa;
  
  @Inject
  @Extension
  private JavaNamesExt _javaNamesExt;
  
  @Inject
  @Extension
  private ProvidedPortsXpt _providedPortsXpt;
  
  @Inject
  @Extension
  private JavaCoreXpt _javaCoreXpt;
  
  protected void _delegatorClass(final OperationInterface iface, final String prefix) {
    String _implementationPackage = this._javaNamesExt.implementationPackage(iface);
    String _plus = (_implementationPackage + ".delegates");
    String _fqnToDirectoryPath = this._javaNamesExt.fqnToDirectoryPath(_plus);
    String _plus_1 = (_fqnToDirectoryPath + "/");
    String _plus_2 = (_plus_1 + prefix);
    String _javaName = this._javaNamesExt.javaName(iface);
    String _plus_3 = (_plus_2 + _javaName);
    final String fileName = (_plus_3 + ".java");
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("package ");
    String _implementationPackage_1 = this._javaNamesExt.implementationPackage(iface);
    _builder.append(_implementationPackage_1, "");
    _builder.append(".delegates;");
    _builder.newLineIfNotEmpty();
    _builder.append("// Delegator class for interface ");
    String _entityName = iface.getEntityName();
    _builder.append(_entityName, "");
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    _builder.append(prefix, "");
    String _javaName_1 = this._javaNamesExt.javaName(iface);
    _builder.append(_javaName_1, "");
    _builder.append(" implements ");
    String _fqn = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn, "");
    _builder.newLineIfNotEmpty();
    _builder.append("{");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("private static org.apache.log4j.Logger logger = ");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.apache.log4j.Logger.getLogger(");
    String _fqn_1 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_1, "\t\t");
    _builder.append(".class.getName());");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("protected ");
    String _fqn_2 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_2, "\t");
    _builder.append(" myInnerPort = null;");
    _builder.newLineIfNotEmpty();
    _builder.append("     ");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public ");
    _builder.append(prefix, "\t");
    String _javaName_2 = this._javaNamesExt.javaName(iface);
    _builder.append(_javaName_2, "\t");
    _builder.append("(");
    String _fqn_3 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_3, "\t");
    _builder.append(" myInnerPort){");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("this.myInnerPort = myInnerPort;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _composedComponentPortHelperMethodsTM = this._providedPortsXpt.composedComponentPortHelperMethodsTM(iface);
    _builder.append(_composedComponentPortHelperMethodsTM, "\t");
    _builder.append("    ");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    {
      EList<OperationSignature> _signatures__OperationInterface = iface.getSignatures__OperationInterface();
      for(final OperationSignature subinterface : _signatures__OperationInterface) {
        _builder.append("\t");
        CharSequence _delegator = this.delegator(subinterface);
        _builder.append(_delegator, "\t");
        _builder.newLineIfNotEmpty();
      }
    }
    _builder.append("  ");
    _builder.append("}");
    _builder.newLine();
    final String fileContent = _builder.toString();
    this.fsa.generateFile(fileName, fileContent);
  }
  
  protected void _delegatorClass(final InfrastructureInterface iface, final String prefix) {
    String _implementationPackage = this._javaNamesExt.implementationPackage(iface);
    String _plus = (_implementationPackage + ".delegates");
    String _fqnToDirectoryPath = this._javaNamesExt.fqnToDirectoryPath(_plus);
    String _plus_1 = (_fqnToDirectoryPath + "/");
    String _plus_2 = (_plus_1 + prefix);
    String _javaName = this._javaNamesExt.javaName(iface);
    String _plus_3 = (_plus_2 + _javaName);
    final String fileName = (_plus_3 + ".java");
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("package ");
    String _implementationPackage_1 = this._javaNamesExt.implementationPackage(iface);
    _builder.append(_implementationPackage_1, "");
    _builder.append(".delegates;");
    _builder.newLineIfNotEmpty();
    _builder.append("// Delegator class for interface ");
    String _entityName = iface.getEntityName();
    _builder.append(_entityName, "");
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    _builder.append(prefix, "");
    String _javaName_1 = this._javaNamesExt.javaName(iface);
    _builder.append(_javaName_1, "");
    _builder.append(" implements ");
    String _fqn = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn, "");
    _builder.newLineIfNotEmpty();
    _builder.append("{");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("private static org.apache.log4j.Logger logger = ");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.apache.log4j.Logger.getLogger(");
    String _fqn_1 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_1, "\t\t");
    _builder.append(".class.getName());");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("protected ");
    String _fqn_2 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_2, "\t");
    _builder.append(" myInnerPort = null;");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public ");
    _builder.append(prefix, "\t");
    String _javaName_2 = this._javaNamesExt.javaName(iface);
    _builder.append(_javaName_2, "\t");
    _builder.append("(");
    String _fqn_3 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_3, "\t");
    _builder.append(" myInnerPort){");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("this.myInnerPort = myInnerPort;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _composedComponentPortHelperMethodsTM = this._providedPortsXpt.composedComponentPortHelperMethodsTM(iface);
    _builder.append(_composedComponentPortHelperMethodsTM, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    {
      EList<InfrastructureSignature> _infrastructureSignatures__InfrastructureInterface = iface.getInfrastructureSignatures__InfrastructureInterface();
      for(final InfrastructureSignature subinterface : _infrastructureSignatures__InfrastructureInterface) {
        CharSequence _delegator = this.delegator(subinterface);
        _builder.append(_delegator, "");
        _builder.newLineIfNotEmpty();
      }
    }
    _builder.append("}");
    _builder.newLine();
    final String fileContent = _builder.toString();
    this.fsa.generateFile(fileName, fileContent);
  }
  
  protected CharSequence _delegator(final OperationSignature os) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("public ");
    CharSequence _operationSignature = this._javaCoreXpt.operationSignature(os);
    _builder.append(_operationSignature, "");
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("logger.debug(\"Delegating ");
    String _entityName = os.getEntityName();
    _builder.append(_entityName, "\t");
    _builder.append("\");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Pre");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("ctx.setEvaluationMode(de.uka.ipd.sdq.simucomframework.variables.stoexvisitor.VariableMode.EXCEPTION_ON_NOT_FOUND);");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _returnTypeTM = this._javaCoreXpt.returnTypeTM(os);
    _builder.append(_returnTypeTM, "\t");
    _builder.append(" result = myInnerPort.");
    String _javaSignature = this._javaNamesExt.javaSignature(os);
    _builder.append(_javaSignature, "\t");
    _builder.append("(");
    _builder.newLineIfNotEmpty();
    _builder.append("\t     ");
    CharSequence _parameterUsageListTM = this._javaCoreXpt.parameterUsageListTM(os);
    _builder.append(_parameterUsageListTM, "\t     ");
    _builder.append(");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Post");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("ctx.setEvaluationMode(de.uka.ipd.sdq.simucomframework.variables.stoexvisitor.VariableMode.RETURN_DEFAULT_ON_NOT_FOUND);");
    _builder.newLine();
    _builder.append("return result;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  protected CharSequence _delegator(final InfrastructureSignature is) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("public ");
    CharSequence _infrastructureSignature = this._javaCoreXpt.infrastructureSignature(is);
    _builder.append(_infrastructureSignature, "");
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("logger.debug(\"Delegating ");
    String _entityName = is.getEntityName();
    _builder.append(_entityName, "\t");
    _builder.append("\");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Pre");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("ctx.setEvaluationMode(de.uka.ipd.sdq.simucomframework.variables.stoexvisitor.VariableMode.EXCEPTION_ON_NOT_FOUND);");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _returnTypeTM = this._javaCoreXpt.returnTypeTM(is);
    _builder.append(_returnTypeTM, "\t");
    _builder.append(" result = myInnerPort.");
    String _javaSignature = this._javaNamesExt.javaSignature(is);
    _builder.append(_javaSignature, "\t");
    _builder.append("(");
    _builder.newLineIfNotEmpty();
    _builder.append("\t     ");
    CharSequence _parameterUsageListTM = this._javaCoreXpt.parameterUsageListTM(is);
    _builder.append(_parameterUsageListTM, "\t     ");
    _builder.append(");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Post");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("ctx.setEvaluationMode(de.uka.ipd.sdq.simucomframework.variables.stoexvisitor.VariableMode.RETURN_DEFAULT_ON_NOT_FOUND);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return result;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public void delegatorClass(final Interface iface, final String prefix) {
    if (iface instanceof InfrastructureInterface) {
      _delegatorClass((InfrastructureInterface)iface, prefix);
      return;
    } else if (iface instanceof OperationInterface) {
      _delegatorClass((OperationInterface)iface, prefix);
      return;
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(iface, prefix).toString());
    }
  }
  
  public CharSequence delegator(final Signature is) {
    if (is instanceof InfrastructureSignature) {
      return _delegator((InfrastructureSignature)is);
    } else if (is instanceof OperationSignature) {
      return _delegator((OperationSignature)is);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(is).toString());
    }
  }
}

==> de.uka.ipd.sdq.pcm.codegen.simucom.source_5.2.2.jar: de/uka/ipd/sdq/pcm/codegen/simucom/transformations/DelegatorClassXpt.java <==
package de.uka.ipd.sdq.pcm.codegen.simucom.transformations;

import com.google.inject.Inject;
import de.uka.ipd.sdq.pcm.codegen.simucom.helper.M2TFileSystemAccess;
import java.util.Arrays;
import org.eclipse.emf.common.util.EList;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import org.palladiosimulator.pcm.repository.InfrastructureInterface;
import org.palladiosimulator.pcm.repository.InfrastructureSignature;
import org.palladiosimulator.pcm.repository.Interface;
import org.palladiosimulator.pcm.repository.OperationInterface;
import org.palladiosimulator.pcm.repository.OperationSignature;
import org.palladiosimulator.pcm.repository.Signature;

@SuppressWarnings("all")
public class DelegatorClassXpt {
  @Inject
  private M2TFileSystemAccess fsa;

  @Inject
  @Extension
  private JavaNamesExt _javaNamesExt;

  @Inject
  @Extension
  private ProvidedPortsXpt _providedPortsXpt;

  @Inject
  @Extension
  private JavaCoreXpt _javaCoreXpt;

  protected void _delegatorClass(final OperationInterface iface, final String prefix) {
    String _implementationPackage = this._javaNamesExt.implementationPackage(iface);
    String _fqnToDirectoryPath = this._javaNamesExt.fqnToDirectoryPath((_implementationPackage + ".delegates"));
    String _plus = (_fqnToDirectoryPath + "/");
    String _plus_1 = (_plus + prefix);
    String _javaName = this._javaNamesExt.javaName(iface);
    String _plus_2 = (_plus_1 + _javaName);
    final String fileName = (_plus_2 + ".java");
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("package ");
    String _implementationPackage_1 = this._javaNamesExt.implementationPackage(iface);
    _builder.append(_implementationPackage_1);
    _builder.append(".delegates;");
    _builder.newLineIfNotEmpty();
    _builder.append("// Delegator class for interface ");
    String _entityName = iface.getEntityName();
    _builder.append(_entityName);
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    _builder.append(prefix);
    String _javaName_1 = this._javaNamesExt.javaName(iface);
    _builder.append(_javaName_1);
    _builder.append(" implements ");
    String _fqn = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn);
    _builder.newLineIfNotEmpty();
    _builder.append("{");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("private static org.apache.log4j.Logger logger = ");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.apache.log4j.Logger.getLogger(");
    String _fqn_1 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_1, "\t\t");
    _builder.append(".class.getName());");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("protected ");
    String _fqn_2 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_2, "\t");
    _builder.append(" myInnerPort = null;");
    _builder.newLineIfNotEmpty();
    _builder.append("     ");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public ");
    _builder.append(prefix, "\t");
    String _javaName_2 = this._javaNamesExt.javaName(iface);
    _builder.append(_javaName_2, "\t");
    _builder.append("(");
    String _fqn_3 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_3, "\t");
    _builder.append(" myInnerPort){");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("this.myInnerPort = myInnerPort;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _composedComponentPortHelperMethodsTM = this._providedPortsXpt.composedComponentPortHelperMethodsTM(iface);
    _builder.append(_composedComponentPortHelperMethodsTM, "\t");
    _builder.append("    ");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    {
      EList<OperationSignature> _signatures__OperationInterface = iface.getSignatures__OperationInterface();
      for(final OperationSignature subinterface : _signatures__OperationInterface) {
        _builder.append("\t");
        CharSequence _delegator = this.delegator(subinterface);
        _builder.append(_delegator, "\t");
        _builder.newLineIfNotEmpty();
      }
    }
    _builder.append("  ");
    _builder.append("}");
    _builder.newLine();
    final String fileContent = _builder.toString();
    this.fsa.generateFile(fileName, fileContent);
  }

  protected void _delegatorClass(final InfrastructureInterface iface, final String prefix) {
    String _implementationPackage = this._javaNamesExt.implementationPackage(iface);
    String _fqnToDirectoryPath = this._javaNamesExt.fqnToDirectoryPath((_implementationPackage + ".delegates"));
    String _plus = (_fqnToDirectoryPath + "/");
    String _plus_1 = (_plus + prefix);
    String _javaName = this._javaNamesExt.javaName(iface);
    String _plus_2 = (_plus_1 + _javaName);
    final String fileName = (_plus_2 + ".java");
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("package ");
    String _implementationPackage_1 = this._javaNamesExt.implementationPackage(iface);
    _builder.append(_implementationPackage_1);
    _builder.append(".delegates;");
    _builder.newLineIfNotEmpty();
    _builder.append("// Delegator class for interface ");
    String _entityName = iface.getEntityName();
    _builder.append(_entityName);
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    _builder.append(prefix);
    String _javaName_1 = this._javaNamesExt.javaName(iface);
    _builder.append(_javaName_1);
    _builder.append(" implements ");
    String _fqn = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn);
    _builder.newLineIfNotEmpty();
    _builder.append("{");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("private static org.apache.log4j.Logger logger = ");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.apache.log4j.Logger.getLogger(");
    String _fqn_1 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_1, "\t\t");
    _builder.append(".class.getName());");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("protected ");
    String _fqn_2 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_2, "\t");
    _builder.append(" myInnerPort = null;");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    _builder.append("public ");
    _builder.append(prefix, "\t");
    String _javaName_2 = this._javaNamesExt.javaName(iface);
    _builder.append(_javaName_2, "\t");
    _builder.append("(");
    String _fqn_3 = this._javaNamesExt.fqn(iface);
    _builder.append(_fqn_3, "\t");
    _builder.append(" myInnerPort){");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("this.myInnerPort = myInnerPort;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _composedComponentPortHelperMethodsTM = this._providedPortsXpt.composedComponentPortHelperMethodsTM(iface);
    _builder.append(_composedComponentPortHelperMethodsTM, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    {
      EList<InfrastructureSignature> _infrastructureSignatures__InfrastructureInterface = iface.getInfrastructureSignatures__InfrastructureInterface();
      for(final InfrastructureSignature subinterface : _infrastructureSignatures__InfrastructureInterface) {
        CharSequence _delegator = this.delegator(subinterface);
        _builder.append(_delegator);
        _builder.newLineIfNotEmpty();
      }
    }
    _builder.append("}");
    _builder.newLine();
    final String fileContent = _builder.toString();
    this.fsa.generateFile(fileName, fileContent);
  }

  protected CharSequence _delegator(final OperationSignature os) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("public ");
    CharSequence _operationSignature = this._javaCoreXpt.operationSignature(os);
    _builder.append(_operationSignature);
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("logger.debug(\"Delegating ");
    String _entityName = os.getEntityName();
    _builder.append(_entityName, "\t");
    _builder.append("\");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Pre");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("ctx.setEvaluationMode(de.uka.ipd.sdq.simucomframework.variables.stoexvisitor.VariableMode.EXCEPTION_ON_NOT_FOUND);");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _returnTypeTM = this._javaCoreXpt.returnTypeTM(os);
    _builder.append(_returnTypeTM, "\t");
    _builder.append(" result = myInnerPort.");
    String _javaSignature = this._javaNamesExt.javaSignature(os);
    _builder.append(_javaSignature, "\t");
    _builder.append("(");
    _builder.newLineIfNotEmpty();
    _builder.append("\t     ");
    CharSequence _parameterUsageListTM = this._javaCoreXpt.parameterUsageListTM(os);
    _builder.append(_parameterUsageListTM, "\t     ");
    _builder.append(");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Post");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("ctx.setEvaluationMode(de.uka.ipd.sdq.simucomframework.variables.stoexvisitor.VariableMode.RETURN_DEFAULT_ON_NOT_FOUND);");
    _builder.newLine();
    _builder.append("return result;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }

  protected CharSequence _delegator(final InfrastructureSignature is) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("public ");
    CharSequence _infrastructureSignature = this._javaCoreXpt.infrastructureSignature(is);
    _builder.append(_infrastructureSignature);
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("logger.debug(\"Delegating ");
    String _entityName = is.getEntityName();
    _builder.append(_entityName, "\t");
    _builder.append("\");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Pre");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("ctx.setEvaluationMode(de.uka.ipd.sdq.simucomframework.variables.stoexvisitor.VariableMode.EXCEPTION_ON_NOT_FOUND);");
    _builder.newLine();
    _builder.append("\t");
    CharSequence _returnTypeTM = this._javaCoreXpt.returnTypeTM(is);
    _builder.append(_returnTypeTM, "\t");
    _builder.append(" result = myInnerPort.");
    String _javaSignature = this._javaNamesExt.javaSignature(is);
    _builder.append(_javaSignature, "\t");
    _builder.append("(");
    _builder.newLineIfNotEmpty();
    _builder.append("\t     ");
    CharSequence _parameterUsageListTM = this._javaCoreXpt.parameterUsageListTM(is);
    _builder.append(_parameterUsageListTM, "\t     ");
    _builder.append(");");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Post");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("ctx.setEvaluationMode(de.uka.ipd.sdq.simucomframework.variables.stoexvisitor.VariableMode.RETURN_DEFAULT_ON_NOT_FOUND);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return result;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }

  public void delegatorClass(final Interface iface, final String prefix) {
    if (iface instanceof InfrastructureInterface) {
      _delegatorClass((InfrastructureInterface)iface, prefix);
      return;
    } else if (iface instanceof OperationInterface) {
      _delegatorClass((OperationInterface)iface, prefix);
      return;
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(iface, prefix).toString());
    }
  }

  public CharSequence delegator(final Signature is) {
    if (is instanceof InfrastructureSignature) {
      return _delegator((InfrastructureSignature)is);
    } else if (is instanceof OperationSignature) {
      return _delegator((OperationSignature)is);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(is).toString());
    }
  }
}
